==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/include/html.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

class KWL_Html {

   function input_form($type,$name,$value='',$size='',$maxlength='') {
      if (!empty($value)) $value = " VALUE=\"$value\"";
      if ($size) $size = " SIZE=\"$size\"";
      if ($maxlength) $maxlength = " MAXLENGTH=\"$maxlength\"";

      return "<INPUT TYPE=\"$type\" NAME=\"$name\"". $size . $maxlength . $value . ">\n";
   }
	
   function check_box($name,$check=0) {
      $tmp = $check ? " CHECKED" : "";
      return "<INPUT TYPE=\"CHECKBOX\" NAME=\"$name\"". $tmp ."> ";
   }

   function textarea($name,$row,$col,$txt='') {
      return "<TEXTAREA NAME=\"$name\" ROWS=\"$row\" COLS=\"$col\" ". KWL_Form_Wrap() .">$txt</TEXTAREA>\n";
   } 
	
   function form_start($act,$name,$upload=0,$method="POST") {
      $tmp = $upload ? " ENCTYPE=\"multipart/form-data\"" : "";
      if (!preg_match('!^http!', $act)) $act = KWL_GetConf("G_URL") ."/". $act;
      return "<FORM ACTION=\"$act\" NAME=\"$name\" METHOD=\"$method\"" . $tmp . ">\n";
   }

   function form_end() {
      return "</FORM>\n";
   }
   
   function table_start($w='',$align='',$boder=0,$cs=0,$cp=0,$bgcolor='') {
      if ($w) $w = " WIDTH=\"$w\"";
      if ($align) $align = " ALIGN=\"$align\"";
      if ($bgcolor) $bgcolor = " BGCOLOR=\"$bgcolor\"";
      return "<TABLE BORDER=\"$boder\" CELLSPACING=\"$cs\" CELLPADDING=\"$cp\"" . $w . $align . $bgcolor .">\n";
   }

   function table_end() {
      return "</TABLE>\n";
   }

   function select($name,$var=array(),$sel='') {
      $ret = "<SELECT NAME=\"$name\">";
      foreach ($var as $v=>$k) {
         $ret .= "<OPTION VALUE=\"$v\"". ($sel == $v ? " SELECTED" : "") ."> "
            . htmlspecialchars($k) . "</OPTION>";
      }
      return $ret . "</SELECT>";
   }

   function radio($name,$var=array(),$sel='') {
      $ret = "";
      foreach ($var as $v=>$k) {
         $ret .= "<INPUT TYPE=\"RADIO\" NAME=\"$name\" VALUE=\"$v\""
         . ($sel == $v ? " CHECKED" : "") ."> " . KWL_PrepareHtml($k) ."\n";
      }
      return $ret;
   }

   function topicsel($topic='',$type='',$name='Topic') {
      global $TOPIC;
      if ($type == "search") $array[0] = _ALLTOPICS;
      foreach ($TOPIC as $A) {
         if ($A['NoPosting']=="1" && $type=="post" && !KWL_GetConf('admin_login')) 
            continue;
         $array[$A['Rid']] = $A['Topic'];
      }
      return $this->select($name,$array,$topic);
}



} /* end of KWL_Html class */

function KWL_Form_Wrap() {
   switch (KWL_GetConf("FORM_WRAP")) {
      case 1:
         $tmp = "WRAP=\"HARD\"";
      break;
      case 2:
         $tmp = "WRAP=\"VIRTUAL\"";
      break;
      default:
         $tmp = "WRAP=\"OFF\"";
   }
   return $tmp;
}

function KWL_QuoteText($str,$writer) {
   $str = "$writer wrote...\n" . $str;
   $str = ereg_replace("\n", "\n> ", $str);
   return KWL_PrepareHtml($str);
}

function KWL_MakeSelectParse($allow,$level) {

   $tags = _USABLE_TAGS;
   $ret = "";
   foreach (KWL_GetConf('HtmlKey') as $tag) {
      $tags .= "&lt;". strtoupper($tag) ."&gt; ";
   }
   $out = new KWL_Html;
   if ($allow) {
      $ret .= "<BR>". _FORMAT . 
         $out->select("ParseLevel",array ( 2 => _USER_PARSE_L2,
                                           3 => _USER_PARSE_L3,
                                           4 => _USER_PARSE_L4 ),
                      $level);
      return $tags . $ret;
   
   } else {
      switch ($level) {
         case "2": $tmp = $tags;  break;
         case "3": $tmp = _AUTOHTML; break;
         case "4": $tmp = _NOHTML;   break;
      }
      return $tmp .
             $out->input_form("hidden","ParseLevel",$level);
   }
}

function KWL_FormResizer($name,$col,$row) {
   if (KWL_GetConf("Language") == "korean") { $left  = ""; $right = ""; $reset = ""; $up	 = ""; $down	 = ""; }
   else { $left  = "Left"; $right = "Right"; $reset = "Reset"; $up = "Up";	$down = "Down"; }
   $value = 5;
   return "<SCRIPT LANGUAGE=JavaScript>
<!--
function fresize(value) {
   if (value == 0) {
      document.$name.cols  = $col;
      document.$name.rows  = $row;
   }
   if (value == 1) {
      if (document.$name.cols > $col) 
         document.$name.cols -= $value;
   }
   if (value == 2) document.$name.cols += $value;
   if (value == 3) {
      if (document.$name.rows > $row)
         document.$name.rows -= $value;
   }
   if (value == 4) document.$name.rows += $value;
}
// -->
</SCRIPT>
<INPUT TYPE=BUTTON VALUE=\"$left\" onClick=\"fresize(1);\" TITLE=\"Col - $value\"><INPUT TYPE=BUTTON VALUE=\"$right\" onClick=\"fresize(2);\" TITLE=\"Col + $value\"><INPUT TYPE=BUTTON VALUE=\"$reset\" onClick=\"fresize(0);\" TITLE=\"Reset\"><INPUT TYPE=BUTTON VALUE=\"$up\" onClick=\"fresize(3);\" TITLE=\"Row - $value\"><INPUT TYPE=BUTTON VALUE=\"$down\" onClick=\"fresize(4);\" TITLE=\"Row + $value\">\n";
}

class KWL_OutputControl {
   var $content;

   function start($f='') {
      ob_start($f);
      ob_implicit_flush(0);
   }

   function end() {
      $this->get();
      print $this->content;
   }

   function return_content() {
      $this->get();
      return $this->content;
   }

   function get() {
      $this->content = ob_get_contents();
      ob_end_clean();
   }

} /* end of KWL_OutputControl class */
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/html.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

class KWL_Html {

   function input_form($type,$name,$value='',$size='',$maxlength='') {
      if (!empty($value)) $value = " value=\"$value\"";
      if ($size) $size = " size=\"$size\"";
      if ($maxlength) $maxlength = " maxlength=\"$maxlength\"";

      return "<input type=\"$type\" name=\"$name\"". $size . $maxlength . $value . " />\n";
   }
	
   function check_box($name,$check=0) {
      $tmp = $check ? " checked=\"checked\"" : "";
      return "<input type=\"checkbox\" name=\"$name\"". $tmp ." /> ";
   }

   function textarea($name,$row,$col,$txt='') {
      return "<textarea name=\"$name\" rows=\"$row\" cols=\"$col\" ". KWL_Form_Wrap() .">$txt</textarea>\n";
   } 
	
   function form_start($act,$name,$upload=0,$method="post") {
      $tmp = $upload ? " enctype=\"multipart/form-data\"" : "";
      if (!preg_match('!^http!', $act)) $act = KWL_GetConf("G_URL") ."/". $act;
      return "<form action=\"$act\" name=\"$name\" method=\"$method\"" . $tmp . ">\n";
   }

   function form_end() {
      return "</form>\n";
   }
   
   function table_start($w='',$align='',$boder=0,$cs=0,$cp=0,$bgcolor='') {
      if ($w) $w = " width=\"$w\"";
      if ($align) $align = " align=\"$align\"";
      if ($bgcolor) $bgcolor = " bgcolor=\"$bgcolor\"";
      return "<table border=\"$boder\" cellspacing=\"$cs\" cellpadding=\"$cp\"" . $w . $align . $bgcolor .">\n";
   }

   function table_end() {
      return "</table>\n";
   }

   function select($name,$var=array(),$sel='') {
      $ret = "<select name=\"$name\">";
      foreach ($var as $v=>$k) {
         $ret .= "<option value=\"$v\"". ($sel == $v ? " selected=\"selected\"" : "") ."> "
            . htmlspecialchars($k) . "</option>";
      }
      return $ret . "</select>";
   }

   function radio($name,$var=array(),$sel='') {
      $ret = "";
      foreach ($var as $v=>$k) {
         $ret .= "<input type=\"radio\" name=\"$name\" value=\"$v\""
         . ($sel == $v ? " checked=\"checked\"" : "") ."> " . KWL_PrepareHtml($k) ."\n";
      }
      return $ret;
   }

   function topicsel($topic='',$type='',$name='Topic') {
      global $TOPIC;
      if ($type == "search") $array[0] = _ALLTOPICS;
      foreach ($TOPIC as $A) {
         if ($A['NoPosting']=="1" && $type=="post" && !KWL_GetConf('admin_login')) 
            continue;
         $array[$A['Rid']] = $A['Topic'];
      }
      return $this->select($name,$array,$topic);
}



} /* end of KWL_Html class */

function KWL_Form_Wrap() {
   switch (KWL_GetConf("FORM_WRAP")) {
      case 1:
         $tmp = "wrap=\"hard\"";
      break;
      case 2:
         $tmp = "wrap=\"virtual\"";
      break;
      default:
         $tmp = "wrap=\"off\"";
   }
   return $tmp;
}

function KWL_QuoteText($str,$writer) {
   $str = "$writer wrote...\n" . $str;
   $str = ereg_replace("\n", "\n> ", $str);
   return KWL_PrepareHtml($str);
}

function KWL_MakeSelectParse($allow,$level) {

   $tags = _USABLE_TAGS;
   $ret = "";
   foreach (KWL_GetConf('HtmlKey') as $tag) {
      $tags .= "&lt;". strtoupper($tag) ."&gt; ";
   }
   $out = new KWL_Html;
   if ($allow) {
      $ret .= "<br />". _FORMAT . 
         $out->select("ParseLevel",array ( 2 => _USER_PARSE_L2,
                                           3 => _USER_PARSE_L3,
                                           4 => _USER_PARSE_L4 ),
                      $level);
      return $tags . $ret;
   
   } else {
      switch ($level) {
         case "2": $tmp = $tags;  break;
         case "3": $tmp = _AUTOHTML; break;
         case "4": $tmp = _NOHTML;   break;
      }
      return $tmp .
             $out->input_form("hidden","ParseLevel",$level);
   }
}

function KWL_FormResizer($name,$col,$row) {
   if (KWL_GetConf("Language") == "korean") { $left  = ""; $right = ""; $reset = ""; $up	 = ""; $down	 = ""; }
   else { $left  = "Left"; $right = "Right"; $reset = "Reset"; $up = "Up";	$down = "Down"; }
   $value = 5;
   return "<script language=\"javascript\" type=\"text/javascript\">
//<![CDATA[
<!--
function fresize(value) {
   if (value == 0) {
      document.$name.cols  = $col;
      document.$name.rows  = $row;
   }
   if (value == 1) {
      if (document.$name.cols > $col) 
         document.$name.cols -= $value;
   }
   if (value == 2) document.$name.cols += $value;
   if (value == 3) {
      if (document.$name.rows > $row)
         document.$name.rows -= $value;
   }
   if (value == 4) document.$name.rows += $value;
}
//-->
//]]>
</script>
<input type=\"button\" value=\"$left\" onclick=\"fresize(1);\" title=\"col - $value\" /><input type=\"button\" value=\"$right\" onclick=\"fresize(2);\" title=\"col + $value\" /><input type=\"button\" value=\"$reset\" onclick=\"fresize(0);\" title=\"reset\" /><input type=\"button\" value=\"$up\" onclick=\"fresize(3);\" title=\"row - $value\" /><input type=\"button\" value=\"$down\" onclick=\"fresize(4);\" title=\"row + $value\" />\n";
}

class KWL_OutputControl {
   var $content;

   function start($f='') {
      ob_start($f);
      ob_implicit_flush(0);
   }

   function end() {
      $this->get();
      print $this->content;
   }

   function return_content() {
      $this->get();
      return $this->content;
   }

   function get() {
      $this->content = ob_get_contents();
      ob_end_clean();
   }

} /* end of KWL_OutputControl class */
?>
